==> qore-1.17.0.tar.bz2: qore-1.17.0/docs/modules/DataProvider/html/annotated_dup.js <==
var annotated_dup =
[
    [ "DataProvider", "namespace_data_provider.html", [
      [ "AbstractDataField", "class_data_provider_1_1_abstract_data_field.html", "class_data_provider_1_1_abstract_data_field" ],
      [ "AbstractDataProcessor", "class_data_provider_1_1_abstract_data_processor.html", "class_data_provider_1_1_abstract_data_processor" ],
      [ "AbstractDataProvider", "class_data_provider_1_1_abstract_data_provider.html", "class_data_provider_1_1_abstract_data_provider" ],
      [ "AbstractDataProviderBulkOperation", "class_data_provider_1_1_abstract_data_provider_bulk_operation.html", "class_data_provider_1_1_abstract_data_provider_bulk_operation" ],
      [ "AbstractDataProviderBulkRecordInterface", "class_data_provider_1_1_abstract_data_provider_bulk_record_interface.html", "class_data_provider_1_1_abstract_data_provider_bulk_record_interface" ],
      [ "AbstractDataProviderFactory", "class_data_provider_1_1_abstract_data_provider_factory.html", "class_data_provider_1_1_abstract_data_provider_factory" ],
      [ "AbstractDataProviderRecordIterator", "class_data_provider_1_1_abstract_data_provider_record_iterator.html", "class_data_provider_1_1_abstract_data_provider_record_iterator" ],
      [ "AbstractDataProviderType", "class_data_provider_1_1_abstract_data_provider_type.html", "class_data_provider_1_1_abstract_data_provider_type" ],
      [ "AbstractEventFilter", "class_data_provider_1_1_abstract_event_filter.html", "class_data_provider_1_1_abstract_event_filter" ],
      [ "AllowedValueInfo", "struct_data_provider_1_1_allowed_value_info.html", "struct_data_provider_1_1_allowed_value_info" ],
      [ "DataFieldInfo", "struct_data_provider_1_1_data_field_info.html", "struct_data_provider_1_1_data_field_info" ],
      [ "DataProvider", "class_data_provider_1_1_data_provider.html", "class_data_provider_1_1_data_provider" ],
      [ "DataProviderBulkRecordIterator", "class_data_provider_1_1_data_provider_bulk_record_iterator.html", "class_data_provider_1_1_data_provider_bulk_record_iterator" ],
      [ "DataProviderExpression", "struct_data_provider_1_1_data_provider_expression.html", "struct_data_provider_1_1_data_provider_expression" ],
      [ "DataProviderExpressionInfo", "struct_data_provider_1_1_data_provider_expression_info.html", "struct_data_provider_1_1_data_provider_expression_info" ],
      [ "DataProviderFactoryInfo", "struct_data_provider_1_1_data_provider_factory_info.html", "struct_data_provider_1_1_data_provider_factory_info" ],
      [ "DataProviderFieldReference", "struct_data_provider_1_1_data_provider_field_reference.html", "struct_data_provider_1_1_data_provider_field_reference" ],
      [ "DataProviderInfo", "struct_data_provider_1_1_data_provider_info.html", "struct_data_provider_1_1_data_provider_info" ],
      [ "DataProviderMessageInfo", "struct_data_provider_1_1_data_provider_message_info.html", "struct_data_provider_1_1_data_provider_message_info" ],
      [ "DataProviderOptionInfo", "struct_data_provider_1_1_data_provider_option_info.html", "struct_data_provider_1_1_data_provider_option_info" ],
      [ "DataProviderPipeline", "class_data_provider_1_1_data_provider_pipeline.html", "class_data_provider_1_1_data_provider_pipeline" ],
      [ "DataProviderPipelineFactory", "class_data_provider_1_1_data_provider_pipeline_factory.html", "class_data_provider_1_1_data_provider_pipeline_factory" ],
      [ "DataProviderSignatureTypeInfo", "struct_data_provider_1_1_data_provider_signature_type_info.html", "struct_data_provider_1_1_data_provider_signature_type_info" ],
      [ "DataProviderSummaryInfo", "struct_data_provider_1_1_data_provider_summary_info.html", "struct_data_provider_1_1_data_provider_summary_info" ],
      [ "DataProviderTypeCache", "class_data_provider_1_1_data_provider_type_cache.html", "class_data_provider_1_1_data_provider_type_cache" ],
      [ "DataProviderTypeEntry", "class_data_provider_1_1_data_provider_type_entry.html", "class_data_provider_1_1_data_provider_type_entry" ],
      [ "DataProviderTypeEntryInfo", "struct_data_provider_1_1_data_provider_type_entry_info.html", "struct_data_provider_1_1_data_provider_type_entry_info" ],
      [ "DataProviderTypeOptionInfo", "struct_data_provider_1_1_data_provider_type_option_info.html", "struct_data_provider_1_1_data_provider_type_option_info" ],
      [ "DataTypeInfo", "struct_data_provider_1_1_data_type_info.html", "struct_data_provider_1_1_data_type_info" ],
      [ "DefaultBulkInserter", "class_data_provider_1_1_default_bulk_inserter.html", "class_data_provider_1_1_default_bulk_inserter" ],
      [ "DefaultBulkRecordIterface", "class_data_provider_1_1_default_bulk_record_iterface.html", "class_data_provider_1_1_default_bulk_record_iterface" ],
      [ "DefaultBulkUpserter", "class_data_provider_1_1_default_bulk_upserter.html", "class_data_provider_1_1_default_bulk_upserter" ],
      [ "DefaultRecordIterator", "class_data_provider_1_1_default_record_iterator.html", "class_data_provider_1_1_default_record_iterator" ],
      [ "DelayedObservable", "class_data_provider_1_1_delayed_observable.html", "class_data_provider_1_1_delayed_observable" ],
      [ "HashDataType", "class_data_provider_1_1_hash_data_type.html", "class_data_provider_1_1_hash_data_type" ],
      [ "HashDeclDataType", "class_data_provider_1_1_hash_decl_data_type.html", "class_data_provider_1_1_hash_decl_data_type" ],
      [ "ListDataType", "class_data_provider_1_1_list_data_type.html", "class_data_provider_1_1_list_data_type" ],
      [ "NullDataProvider", "class_data_provider_1_1_null_data_provider.html", "class_data_provider_1_1_null_data_provider" ],
      [ "NullDataProviderFactory", "class_data_provider_1_1_null_data_provider_factory.html", "class_data_provider_1_1_null_data_provider_factory" ],
      [ "Observable", "class_data_provider_1_1_observable.html", "class_data_provider_1_1_observable" ],
      [ "Observer", "class_data_provider_1_1_observer.html", "class_data_provider_1_1_observer" ],
      [ "PipelineFactoryInfo", "struct_data_provider_1_1_pipeline_factory_info.html", "struct_data_provider_1_1_pipeline_factory_info" ],
      [ "PipelineInfo", "struct_data_provider_1_1_pipeline_info.html", "struct_data_provider_1_1_pipeline_info" ],
      [ "PipelineOptionInfo", "struct_data_provider_1_1_pipeline_option_info.html", "struct_data_provider_1_1_pipeline_option_info" ],
      [ "PipelineQueue", "class_data_provider_1_1_pipeline_queue.html", "class_data_provider_1_1_pipeline_queue" ],
      [ "QoreBase64BinaryDataType", "class_data_provider_1_1_qore_base64_binary_data_type.html", "class_data_provider_1_1_qore_base64_binary_data_type" ],
      [ "QoreBase64BinaryOrNothingDataType", "class_data_provider_1_1_qore_base64_binary_or_nothing_data_type.html", "class_data_provider_1_1_qore_base64_binary_or_nothing_data_type" ],
      [ "QoreBinaryDataType", "class_data_provider_1_1_qore_binary_data_type.html", "class_data_provider_1_1_qore_binary_data_type" ],
      [ "QoreBinaryDataTypeBase", "class_data_provider_1_1_qore_binary_data_type_base.html", "class_data_provider_1_1_qore_binary_data_type_base" ],
      [ "QoreBinaryOrNothingDataType", "class_data_provider_1_1_qore_binary_or_nothing_data_type.html", "class_data_provider_1_1_qore_binary_or_nothing_data_type" ],
      [ "QoreBoolDataType", "class_data_provider_1_1_qore_bool_data_type.html", "class_data_provider_1_1_qore_bool_data_type" ],
      [ "QoreBoolDataTypeBase", "class_data_provider_1_1_qore_bool_data_type_base.html", "class_data_provider_1_1_qore_bool_data_type_base" ],
      [ "QoreBoolOrNothingDataType", "class_data_provider_1_1_qore_bool_or_nothing_data_type.html", "class_data_provider_1_1_qore_bool_or_nothing_data_type" ],
      [ "QoreDataField", "class_data_provider_1_1_qore_data_field.html", "class_data_provider_1_1_qore_data_field" ],
      [ "QoreDataType", "class_data_provider_1_1_qore_data_type.html", "class_data_provider_1_1_qore_data_type" ],
      [ "QoreDateDataType", "class_data_provider_1_1_qore_date_data_type.html", "class_data_provider_1_1_qore_date_data_type" ],
      [ "QoreDateDataTypeBase", "class_data_provider_1_1_qore_date_data_type_base.html", "class_data_provider_1_1_qore_date_data_type_base" ],
      [ "QoreDateOrNothingDataType", "class_data_provider_1_1_qore_date_or_nothing_data_type.html", "class_data_provider_1_1_qore_date_or_nothing_data_type" ],
      [ "QoreFloatDataType", "class_data_provider_1_1_qore_float_data_type.html", "class_data_provider_1_1_qore_float_data_type" ],
      [ "QoreFloatDataTypeBase", "class_data_provider_1_1_qore_float_data_type_base.html", "class_data_provider_1_1_qore_float_data_type_base" ],
      [ "QoreFloatOrNothingDataType", "class_data_provider_1_1_qore_float_or_nothing_data_type.html", "class_data_provider_1_1_qore_float_or_nothing_data_type" ],
      [ "QoreHashDataType", "class_data_provider_1_1_qore_hash_data_type.html", "class_data_provider_1_1_qore_hash_data_type" ],
      [ "QoreHexBinaryDataType", "class_data_provider_1_1_qore_hex_binary_data_type.html", "class_data_provider_1_1_qore_hex_binary_data_type" ],
      [ "QoreHexBinaryOrNothingDataType", "class_data_provider_1_1_qore_hex_binary_or_nothing_data_type.html", "class_data_provider_1_1_qore_hex_binary_or_nothing_data_type" ],
      [ "QoreIntDataType", "class_data_provider_1_1_qore_int_data_type.html", "class_data_provider_1_1_qore_int_data_type" ],
      [ "QoreIntDataTypeBase", "class_data_provider_1_1_qore_int_data_type_base.html", "class_data_provider_1_1_qore_int_data_type_base" ],
      [ "QoreIntOrNothingDataType", "class_data_provider_1_1_qore_int_or_nothing_data_type.html", "class_data_provider_1_1_qore_int_or_nothing_data_type" ],
      [ "QoreListDataType", "class_data_provider_1_1_qore_list_data_type.html", "class_data_provider_1_1_qore_list_data_type" ],
      [ "QoreNumberDataType", "class_data_provider_1_1_qore_number_data_type.html", "class_data_provider_1_1_qore_number_data_type" ],
      [ "QoreNumberDataTypeBase", "class_data_provider_1_1_qore_number_data_type_base.html", "class_data_provider_1_1_qore_number_data_type_base" ],
      [ "QoreNumberOrNothingDataType", "class_data_provider_1_1_qore_number_or_nothing_data_type.html", "class_data_provider_1_1_qore_number_or_nothing_data_type" ],
      [ "QoreSoftBinaryDataType", "class_data_provider_1_1_qore_soft_binary_data_type.html", "class_data_provider_1_1_qore_soft_binary_data_type" ],
      [ "QoreSoftBinaryNoNullDataType", "class_data_provider_1_1_qore_soft_binary_no_null_data_type.html", "class_data_provider_1_1_qore_soft_binary_no_null_data_type" ],
      [ "QoreSoftBinaryOrNothingDataType", "class_data_provider_1_1_qore_soft_binary_or_nothing_data_type.html", "class_data_provider_1_1_qore_soft_binary_or_nothing_data_type" ],
      [ "QoreSoftBoolDataType", "class_data_provider_1_1_qore_soft_bool_data_type.html", "class_data_provider_1_1_qore_soft_bool_data_type" ],
      [ "QoreSoftBoolNoNullDataType", "class_data_provider_1_1_qore_soft_bool_no_null_data_type.html", null ],
      [ "QoreSoftBoolOrNothingDataType", "class_data_provider_1_1_qore_soft_bool_or_nothing_data_type.html", "class_data_provider_1_1_qore_soft_bool_or_nothing_data_type" ],
      [ "QoreSoftDateDataType", "class_data_provider_1_1_qore_soft_date_data_type.html", "class_data_provider_1_1_qore_soft_date_data_type" ],
      [ "QoreSoftDateNoNullDataType", "class_data_provider_1_1_qore_soft_date_no_null_data_type.html", "class_data_provider_1_1_qore_soft_date_no_null_data_type" ],
      [ "QoreSoftDateOrNothingDataType", "class_data_provider_1_1_qore_soft_date_or_nothing_data_type.html", "class_data_provider_1_1_qore_soft_date_or_nothing_data_type" ],
      [ "QoreSoftFloatDataType", "class_data_provider_1_1_qore_soft_float_data_type.html", "class_data_provider_1_1_qore_soft_float_data_type" ],
      [ "QoreSoftFloatNoNullDataType", "class_data_provider_1_1_qore_soft_float_no_null_data_type.html", "class_data_provider_1_1_qore_soft_float_no_null_data_type" ],
      [ "QoreSoftFloatOrNothingDataType", "class_data_provider_1_1_qore_soft_float_or_nothing_data_type.html", "class_data_provider_1_1_qore_soft_float_or_nothing_data_type" ],
      [ "QoreSoftIntDataType", "class_data_provider_1_1_qore_soft_int_data_type.html", "class_data_provider_1_1_qore_soft_int_data_type" ],
      [ "QoreSoftIntNoNullDataType", "class_data_provider_1_1_qore_soft_int_no_null_data_type.html", "class_data_provider_1_1_qore_soft_int_no_null_data_type" ],
      [ "QoreSoftIntOrNothingDataType", "class_data_provider_1_1_qore_soft_int_or_nothing_data_type.html", "class_data_provider_1_1_qore_soft_int_or_nothing_data_type" ],
      [ "QoreSoftNumberDataType", "class_data_provider_1_1_qore_soft_number_data_type.html", "class_data_provider_1_1_qore_soft_number_data_type" ],
      [ "QoreSoftNumberNoNullDataType", "class_data_provider_1_1_qore_soft_number_no_null_data_type.html", "class_data_provider_1_1_qore_soft_number_no_null_data_type" ],
      [ "QoreSoftNumberOrNothingDataType", "class_data_provider_1_1_qore_soft_number_or_nothing_data_type.html", "class_data_provider_1_1_qore_soft_number_or_nothing_data_type" ],
      [ "QoreSoftStringDataType", "class_data_provider_1_1_qore_soft_string_data_type.html", "class_data_provider_1_1_qore_soft_string_data_type" ],
      [ "QoreSoftStringOrNothingDataType", "class_data_provider_1_1_qore_soft_string_or_nothing_data_type.html", "class_data_provider_1_1_qore_soft_string_or_nothing_data_type" ],
      [ "QoreStringDataType", "class_data_provider_1_1_qore_string_data_type.html", "class_data_provider_1_1_qore_string_data_type" ],
      [ "QoreStringDataTypeBase", "class_data_provider_1_1_qore_string_data_type_base.html", "class_data_provider_1_1_qore_string_data_type_base" ],
      [ "QoreStringOrNothingDataType", "class_data_provider_1_1_qore_string_or_nothing_data_type.html", "class_data_provider_1_1_qore_string_or_nothing_data_type" ],
      [ "SearchOperatorInfo", "struct_data_provider_1_1_search_operator_info.html", "struct_data_provider_1_1_search_operator_info" ],
      [ "SoftListDataType", "class_data_provider_1_1_soft_list_data_type.html", "class_data_provider_1_1_soft_list_data_type" ]
    ] ]
];

==> qore-1.19.2.tar.bz2: qore-1.19.2/docs/modules/DataProvider/html/annotated_dup.js <==
var annotated_dup =
[
    [ "DataProvider", "namespace_data_provider.html", [
      [ "AbstractDataField", "class_data_provider_1_1_abstract_data_field.html", "class_data_provider_1_1_abstract_data_field" ],
      [ "AbstractDataProcessor", "class_data_provider_1_1_abstract_data_processor.html", "class_data_provider_1_1_abstract_data_processor" ],
      [ "AbstractDataProvider", "class_data_provider_1_1_abstract_data_provider.html", "class_data_provider_1_1_abstract_data_provider" ],
      [ "AbstractDataProviderBulkOperation", "class_data_provider_1_1_abstract_data_provider_bulk_operation.html", "class_data_provider_1_1_abstract_data_provider_bulk_operation" ],
      [ "AbstractDataProviderBulkRecordInterface", "class_data_provider_1_1_abstract_data_provider_bulk_record_interface.html", "class_data_provider_1_1_abstract_data_provider_bulk_record_interface" ],
      [ "AbstractDataProviderFactory", "class_data_provider_1_1_abstract_data_provider_factory.html", "class_data_provider_1_1_abstract_data_provider_factory" ],
      [ "AbstractDataProviderRecordIterator", "class_data_provider_1_1_abstract_data_provider_record_iterator.html", "class_data_provider_1_1_abstract_data_provider_record_iterator" ],
      [ "AbstractDataProviderType", "class_data_provider_1_1_abstract_data_provider_type.html", "class_data_provider_1_1_abstract_data_provider_type" ],
      [ "AbstractEventFilter", "class_data_provider_1_1_abstract_event_filter.html", "class_data_provider_1_1_abstract_event_filter" ],
      [ "AllowedValueInfo", "struct_data_provider_1_1_allowed_value_info.html", "struct_data_provider_1_1_allowed_value_info" ],
      [ "DataFieldInfo", "struct_data_provider_1_1_data_field_info.html", "struct_data_provider_1_1_data_field_info" ],
      [ "DataProvider", "class_data_provider_1_1_data_provider.html", "class_data_provider_1_1_data_provider" ],
      [ "DataProviderBulkRecordIterator", "class_data_provider_1_1_data_provider_bulk_record_iterator.html", "class_data_provider_1_1_data_provider_bulk_record_iterator" ],
      [ "DataProviderExpression", "struct_data_provider_1_1_data_provider_expression.html", "struct_data_provider_1_1_data_provider_expression" ],
      [ "DataProviderExpressionInfo", "struct_data_provider_1_1_data_provider_expression_info.html", "struct_data_provider_1_1_data_provider_expression_info" ],
      [ "DataProviderFactoryInfo", "struct_data_provider_1_1_data_provider_factory_info.html", "struct_data_provider_1_1_data_provider_factory_info" ],
      [ "DataProviderFieldReference", "struct_data_provider_1_1_data_provider_field_reference.html", "struct_data_provider_1_1_data_provider_field_reference" ],
      [ "DataProviderInfo", "struct_data_provider_1_1_data_provider_info.html", "struct_data_provider_1_1_data_provider_info" ],
      [ "DataProviderMessageInfo", "struct_data_provider_1_1_data_provider_message_info.html", "struct_data_provider_1_1_data_provider_message_info" ],
      [ "DataProviderOptionInfo", "struct_data_provider_1_1_data_provider_option_info.html", "struct_data_provider_1_1_data_provider_option_info" ],
      [ "DataProviderPipeline", "class_data_provider_1_1_data_provider_pipeline.html", "class_data_provider_1_1_data_provider_pipeline" ],
      [ "DataProviderPipelineFactory", "class_data_provider_1_1_data_provider_pipeline_factory.html", "class_data_provider_1_1_data_provider_pipeline_factory" ],
      [ "DataProviderSignatureTypeInfo", "struct_data_provider_1_1_data_provider_signature_type_info.html", "struct_data_provider_1_1_data_provider_signature_type_info" ],
      [ "DataProviderSummaryInfo", "struct_data_provider_1_1_data_provider_summary_info.html", "struct_data_provider_1_1_data_provider_summary_info" ],
      [ "DataProviderTypeCache", "class_data_provider_1_1_data_provider_type_cache.html", "class_data_provider_1_1_data_provider_type_cache" ],
      [ "DataProviderTypeEntry", "class_data_provider_1_1_data_provider_type_entry.html", "class_data_provider_1_1_data_provider_type_entry" ],
      [ "DataProviderTypeEntryInfo", "struct_data_provider_1_1_data_provider_type_entry_info.html", "struct_data_provider_1_1_data_provider_type_entry_info" ],
      [ "DataProviderTypeOptionInfo", "struct_data_provider_1_1_data_provider_type_option_info.html", "struct_data_provider_1_1_data_provider_type_option_info" ],
      [ "DataTypeInfo", "struct_data_provider_1_1_data_type_info.html", "struct_data_provider_1_1_data_type_info" ],
      [ "DefaultBulkInserter", "class_data_provider_1_1_default_bulk_inserter.html", "class_data_provider_1_1_default_bulk_inserter" ],
      [ "DefaultBulkRecordIterface", "class_data_provider_1_1_default_bulk_record_iterface.html", "class_data_provider_1_1_default_bulk_record_iterface" ],
      [ "DefaultBulkUpserter", "class_data_provider_1_1_default_bulk_upserter.html", "class_data_provider_1_1_default_bulk_upserter" ],
      [ "DefaultRecordIterator", "class_data_provider_1_1_default_record_iterator.html", "class_data_provider_1_1_default_record_iterator" ],
      [ "DelayedObservable", "class_data_provider_1_1_delayed_observable.html", "class_data_provider_1_1_delayed_observable" ],
      [ "HashDataType", "class_data_provider_1_1_hash_data_type.html", "class_data_provider_1_1_hash_data_type" ],
      [ "HashDeclDataType", "class_data_provider_1_1_hash_decl_data_type.html", "class_data_provider_1_1_hash_decl_data_type" ],
      [ "ListDataType", "class_data_provider_1_1_list_data_type.html", "class_data_provider_1_1_list_data_type" ],
      [ "NullDataProvider", "class_data_provider_1_1_null_data_provider.html", "class_data_provider_1_1_null_data_provider" ],
      [ "NullDataProviderFactory", "class_data_provider_1_1_null_data_provider_factory.html", "class_data_provider_1_1_null_data_provider_factory" ],
      [ "Observable", "class_data_provider_1_1_observable.html", "class_data_provider_1_1_observable" ],
      [ "Observer", "class_data_provider_1_1_observer.html", "class_data_provider_1_1_observer" ],
      [ "PipelineFactoryInfo", "struct_data_provider_1_1_pipeline_factory_info.html", "struct_data_provider_1_1_pipeline_factory_info" ],
      [ "PipelineInfo", "struct_data_provider_1_1_pipeline_info.html", "struct_data_provider_1_1_pipeline_info" ],
      [ "PipelineOptionInfo", "struct_data_provider_1_1_pipeline_option_info.html", "struct_data_provider_1_1_pipeline_option_info" ],
      [ "PipelineQueue", "class_data_provider_1_1_pipeline_queue.html", "class_data_provider_1_1_pipeline_queue" ],
      [ "QoreBase64BinaryDataType", "class_data_provider_1_1_qore_base64_binary_data_type.html", "class_data_provider_1_1_qore_base64_binary_data_type" ],
      [ "QoreBase64BinaryOrNothingDataType", "class_data_provider_1_1_qore_base64_binary_or_nothing_data_type.html", "class_data_provider_1_1_qore_base64_binary_or_nothing_data_type" ],
      [ "QoreBinaryDataType", "class_data_provider_1_1_qore_binary_data_type.html", "class_data_provider_1_1_qore_binary_data_type" ],
      [ "QoreBinaryDataTypeBase", "class_data_provider_1_1_qore_binary_data_type_base.html", "class_data_provider_1_1_qore_binary_data_type_base" ],
      [ "QoreBinaryOrNothingDataType", "class_data_provider_1_1_qore_binary_or_nothing_data_type.html", "class_data_provider_1_1_qore_binary_or_nothing_data_type" ],
      [ "QoreBoolDataType", "class_data_provider_1_1_qore_bool_data_type.html", "class_data_provider_1_1_qore_bool_data_type" ],
      [ "QoreBoolDataTypeBase", "class_data_provider_1_1_qore_bool_data_type_base.html", "class_data_provider_1_1_qore_bool_data_type_base" ],
      [ "QoreBoolOrNothingDataType", "class_data_provider_1_1_qore_bool_or_nothing_data_type.html", "class_data_provider_1_1_qore_bool_or_nothing_data_type" ],
      [ "QoreDataField", "class_data_provider_1_1_qore_data_field.html", "class_data_provider_1_1_qore_data_field" ],
      [ "QoreDataType", "class_data_provider_1_1_qore_data_type.html", "class_data_provider_1_1_qore_data_type" ],
      [ "QoreDateDataType", "class_data_provider_1_1_qore_date_data_type.html", "class_data_provider_1_1_qore_date_data_type" ],
      [ "QoreDateDataTypeBase", "class_data_provider_1_1_qore_date_data_type_base.html", "class_data_provider_1_1_qore_date_data_type_base" ],
      [ "QoreDateOrNothingDataType", "class_data_provider_1_1_qore_date_or_nothing_data_type.html", "class_data_provider_1_1_qore_date_or_nothing_data_type" ],
      [ "QoreFloatDataType", "class_data_provider_1_1_qore_float_data_type.html", "class_data_provider_1_1_qore_float_data_type" ],
      [ "QoreFloatDataTypeBase", "class_data_provider_1_1_qore_float_data_type_base.html", "class_data_provider_1_1_qore_float_data_type_base" ],
      [ "QoreFloatOrNothingDataType", "class_data_provider_1_1_qore_float_or_nothing_data_type.html", "class_data_provider_1_1_qore_float_or_nothing_data_type" ],
      [ "QoreHashDataType", "class_data_provider_1_1_qore_hash_data_type.html", "class_data_provider_1_1_qore_hash_data_type" ],
      [ "QoreHexBinaryDataType", "class_data_provider_1_1_qore_hex_binary_data_type.html", "class_data_provider_1_1_qore_hex_binary_data_type" ],
      [ "QoreHexBinaryOrNothingDataType", "class_data_provider_1_1_qore_hex_binary_or_nothing_data_type.html", "class_data_provider_1_1_qore_hex_binary_or_nothing_data_type" ],
      [ "QoreIntDataType", "class_data_provider_1_1_qore_int_data_type.html", "class_data_provider_1_1_qore_int_data_type" ],
      [ "QoreIntDataTypeBase", "class_data_provider_1_1_qore_int_data_type_base.html", "class_data_provider_1_1_qore_int_data_type_base" ],
      [ "QoreIntOrNothingDataType", "class_data_provider_1_1_qore_int_or_nothing_data_type.html", "class_data_provider_1_1_qore_int_or_nothing_data_type" ],
      [ "QoreListDataType", "class_data_provider_1_1_qore_list_data_type.html", "class_data_provider_1_1_qore_list_data_type" ],
      [ "QoreNumberDataType", "class_data_provider_1_1_qore_number_data_type.html", "class_data_provider_1_1_qore_number_data_type" ],
      [ "QoreNumberDataTypeBase", "class_data_provider_1_1_qore_number_data_type_base.html", "class_data_provider_1_1_qore_number_data_type_base" ],
      [ "QoreNumberOrNothingDataType", "class_data_provider_1_1_qore_number_or_nothing_data_type.html", "class_data_provider_1_1_qore_number_or_nothing_data_type" ],
      [ "QoreSoftBinaryDataType", "class_data_provider_1_1_qore_soft_binary_data_type.html", "class_data_provider_1_1_qore_soft_binary_data_type" ],
      [ "QoreSoftBinaryNoNullDataType", "class_data_provider_1_1_qore_soft_binary_no_null_data_type.html", "class_data_provider_1_1_qore_soft_binary_no_null_data_type" ],
      [ "QoreSoftBinaryOrNothingDataType", "class_data_provider_1_1_qore_soft_binary_or_nothing_data_type.html", "class_data_provider_1_1_qore_soft_binary_or_nothing_data_type" ],
      [ "QoreSoftBoolDataType", "class_data_provider_1_1_qore_soft_bool_data_type.html", "class_data_provider_1_1_qore_soft_bool_data_type" ],
      [ "QoreSoftBoolNoNullDataType", "class_data_provider_1_1_qore_soft_bool_no_null_data_type.html", "class_data_provider_1_1_qore_soft_bool_no_null_data_type" ],
      [ "QoreSoftBoolOrNothingDataType", "class_data_provider_1_1_qore_soft_bool_or_nothing_data_type.html", "class_data_provider_1_1_qore_soft_bool_or_nothing_data_type" ],
      [ "QoreSoftDateDataType", "class_data_provider_1_1_qore_soft_date_data_type.html", "class_data_provider_1_1_qore_soft_date_data_type" ],
      [ "QoreSoftDateNoNullDataType", "class_data_provider_1_1_qore_soft_date_no_null_data_type.html", "class_data_provider_1_1_qore_soft_date_no_null_data_type" ],
      [ "QoreSoftDateOrNothingDataType", "class_data_provider_1_1_qore_soft_date_or_nothing_data_type.html", "class_data_provider_1_1_qore_soft_date_or_nothing_data_type" ],
      [ "QoreSoftFloatDataType", "class_data_provider_1_1_qore_soft_float_data_type.html", "class_data_provider_1_1_qore_soft_float_data_type" ],
      [ "QoreSoftFloatNoNullDataType", "class_data_provider_1_1_qore_soft_float_no_null_data_type.html", "class_data_provider_1_1_qore_soft_float_no_null_data_type" ],
      [ "QoreSoftFloatOrNothingDataType", "class_data_provider_1_1_qore_soft_float_or_nothing_data_type.html", "class_data_provider_1_1_qore_soft_float_or_nothing_data_type" ],
      [ "QoreSoftIntDataType", "class_data_provider_1_1_qore_soft_int_data_type.html", "class_data_provider_1_1_qore_soft_int_data_type" ],
      [ "QoreSoftIntNoNullDataType", "class_data_provider_1_1_qore_soft_int_no_null_data_type.html", "class_data_provider_1_1_qore_soft_int_no_null_data_type" ],
      [ "QoreSoftIntOrNothingDataType", "class_data_provider_1_1_qore_soft_int_or_nothing_data_type.html", "class_data_provider_1_1_qore_soft_int_or_nothing_data_type" ],
      [ "QoreSoftNumberDataType", "class_data_provider_1_1_qore_soft_number_data_type.html", "class_data_provider_1_1_qore_soft_number_data_type" ],
      [ "QoreSoftNumberNoNullDataType", "class_data_provider_1_1_qore_soft_number_no_null_data_type.html", "class_data_provider_1_1_qore_soft_number_no_null_data_type" ],
      [ "QoreSoftNumberOrNothingDataType", "class_data_provider_1_1_qore_soft_number_or_nothing_data_type.html", "class_data_provider_1_1_qore_soft_number_or_nothing_data_type" ],
      [ "QoreSoftStringDataType", "class_data_provider_1_1_qore_soft_string_data_type.html", "class_data_provider_1_1_qore_soft_string_data_type" ],
      [ "QoreSoftStringOrNothingDataType", "class_data_provider_1_1_qore_soft_string_or_nothing_data_type.html", "class_data_provider_1_1_qore_soft_string_or_nothing_data_type" ],
      [ "QoreStringDataType", "class_data_provider_1_1_qore_string_data_type.html", "class_data_provider_1_1_qore_string_data_type" ],
      [ "QoreStringDataTypeBase", "class_data_provider_1_1_qore_string_data_type_base.html", "class_data_provider_1_1_qore_string_data_type_base" ],
      [ "QoreStringOrNothingDataType", "class_data_provider_1_1_qore_string_or_nothing_data_type.html", "class_data_provider_1_1_qore_string_or_nothing_data_type" ],
      [ "SearchOperatorInfo", "struct_data_provider_1_1_search_operator_info.html", "struct_data_provider_1_1_search_operator_info" ],
      [ "SoftListDataType", "class_data_provider_1_1_soft_list_data_type.html", "class_data_provider_1_1_soft_list_data_type" ]
    ] ]
];
